indicoio-py
===============

A wrapper for the `indico API <http://indico.io>`__.

The indico API is free to use, and no training data is required.

Installation
------------

From PyPI:

.. code:: bash

    pip install indico-client

From source:

.. code:: bash

    git clone https://github.com/IndicoDataSolutions/indico-client-python.git
    python setup.py install
